@@ -136,12 +136,14 @@ int do_macos_iokit(int update_every, usec_t dt) {
                         total_disk_writes += diskstat.bytes_write;
                     }
 
-                    st = rrdset_find_bytype("disk", diskstat.name);
+                    st = rrdset_find_bytype_localhost("disk", diskstat.name);
                     if (unlikely(!st)) {
-                        st = rrdset_create("disk", diskstat.name, NULL, diskstat.name, "disk.io", "Disk I/O Bandwidth", "kilobytes/s", 2000, update_every, RRDSET_TYPE_AREA);
+                        st = rrdset_create_localhost("disk", diskstat.name, NULL, diskstat.name, "disk.io"
+                                                     , "Disk I/O Bandwidth", "kilobytes/s", 2000, update_every
+                                                     , RRDSET_TYPE_AREA);
 
-                        rrddim_add(st, "reads", NULL, 1, 1024, RRDDIM_INCREMENTAL);
-                        rrddim_add(st, "writes", NULL, -1, 1024, RRDDIM_INCREMENTAL);
+                        rrddim_add(st, "reads", NULL, 1, 1024, RRD_ALGORITHM_INCREMENTAL);
+                        rrddim_add(st, "writes", NULL, -1, 1024, RRD_ALGORITHM_INCREMENTAL);
                     }
                     else rrdset_next(st);
 
@@ -161,13 +163,15 @@ int do_macos_iokit(int update_every, usec_t dt) {
                         CFNumberGetValue(number, kCFNumberSInt64Type, &diskstat.writes);
                     }
 
-                    st = rrdset_find_bytype("disk_ops", diskstat.name);
+                    st = rrdset_find_bytype_localhost("disk_ops", diskstat.name);
                     if (unlikely(!st)) {
-                        st = rrdset_create("disk_ops", diskstat.name, NULL, diskstat.name, "disk.ops", "Disk Completed I/O Operations", "operations/s", 2001, update_every, RRDSET_TYPE_LINE);
-                        st->isdetail = 1;
+                        st = rrdset_create_localhost("disk_ops", diskstat.name, NULL, diskstat.name, "disk.ops"
+                                                     , "Disk Completed I/O Operations", "operations/s", 2001
+                                                     , update_every, RRDSET_TYPE_LINE);
+                        rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                        rrddim_add(st, "reads", NULL, 1, 1, RRDDIM_INCREMENTAL);
-                        rrddim_add(st, "writes", NULL, -1, 1, RRDDIM_INCREMENTAL);
+                        rrddim_add(st, "reads", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+                        rrddim_add(st, "writes", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
                     }
                     else rrdset_next(st);
 
@@ -187,12 +191,14 @@ int do_macos_iokit(int update_every, usec_t dt) {
                         CFNumberGetValue(number, kCFNumberSInt64Type, &diskstat.time_write);
                     }
 
-                    st = rrdset_find_bytype("disk_util", diskstat.name);
+                    st = rrdset_find_bytype_localhost("disk_util", diskstat.name);
                     if (unlikely(!st)) {
-                        st = rrdset_create("disk_util", diskstat.name, NULL, diskstat.name, "disk.util", "Disk Utilization Time", "% of time working", 2004, update_every, RRDSET_TYPE_AREA);
-                        st->isdetail = 1;
+                        st = rrdset_create_localhost("disk_util", diskstat.name, NULL, diskstat.name, "disk.util"
+                                                     , "Disk Utilization Time", "% of time working", 2004, update_every
+                                                     , RRDSET_TYPE_AREA);
+                        rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                        rrddim_add(st, "utilization", NULL, 1, 10000000, RRDDIM_INCREMENTAL);
+                        rrddim_add(st, "utilization", NULL, 1, 10000000, RRD_ALGORITHM_INCREMENTAL);
                     }
                     else rrdset_next(st);
 
@@ -212,13 +218,15 @@ int do_macos_iokit(int update_every, usec_t dt) {
                         CFNumberGetValue(number, kCFNumberSInt64Type, &diskstat.latency_write);
                     }
 
-                    st = rrdset_find_bytype("disk_iotime", diskstat.name);
+                    st = rrdset_find_bytype_localhost("disk_iotime", diskstat.name);
                     if (unlikely(!st)) {
-                        st = rrdset_create("disk_iotime", diskstat.name, NULL, diskstat.name, "disk.iotime", "Disk Total I/O Time", "milliseconds/s", 2022, update_every, RRDSET_TYPE_LINE);
-                        st->isdetail = 1;
+                        st = rrdset_create_localhost("disk_iotime", diskstat.name, NULL, diskstat.name, "disk.iotime"
+                                                     , "Disk Total I/O Time", "milliseconds/s", 2022, update_every
+                                                     , RRDSET_TYPE_LINE);
+                        rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                        rrddim_add(st, "reads", NULL, 1, 1000000, RRDDIM_INCREMENTAL);
-                        rrddim_add(st, "writes", NULL, -1, 1000000, RRDDIM_INCREMENTAL);
+                        rrddim_add(st, "reads", NULL, 1, 1000000, RRD_ALGORITHM_INCREMENTAL);
+                        rrddim_add(st, "writes", NULL, -1, 1000000, RRD_ALGORITHM_INCREMENTAL);
                     }
                     else rrdset_next(st);
 
@@ -236,13 +244,15 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                         // --------------------------------------------------------------------
 
-                        st = rrdset_find_bytype("disk_await", diskstat.name);
+                        st = rrdset_find_bytype_localhost("disk_await", diskstat.name);
                         if (unlikely(!st)) {
-                            st = rrdset_create("disk_await", diskstat.name, NULL, diskstat.name, "disk.await", "Average Completed I/O Operation Time", "ms per operation", 2005, update_every, RRDSET_TYPE_LINE);
-                            st->isdetail = 1;
+                            st = rrdset_create_localhost("disk_await", diskstat.name, NULL, diskstat.name, "disk.await"
+                                                         , "Average Completed I/O Operation Time", "ms per operation"
+                                                         , 2005, update_every, RRDSET_TYPE_LINE);
+                            rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                            rrddim_add(st, "reads", NULL, 1, 1000000, RRDDIM_ABSOLUTE);
-                            rrddim_add(st, "writes", NULL, -1, 1000000, RRDDIM_ABSOLUTE);
+                            rrddim_add(st, "reads", NULL, 1, 1000000, RRD_ALGORITHM_ABSOLUTE);
+                            rrddim_add(st, "writes", NULL, -1, 1000000, RRD_ALGORITHM_ABSOLUTE);
                         }
                         else rrdset_next(st);
 
@@ -254,13 +264,16 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                         // --------------------------------------------------------------------
 
-                        st = rrdset_find_bytype("disk_avgsz", diskstat.name);
+                        st = rrdset_find_bytype_localhost("disk_avgsz", diskstat.name);
                         if (unlikely(!st)) {
-                            st = rrdset_create("disk_avgsz", diskstat.name, NULL, diskstat.name, "disk.avgsz", "Average Completed I/O Operation Bandwidth", "kilobytes per operation", 2006, update_every, RRDSET_TYPE_AREA);
-                            st->isdetail = 1;
+                            st = rrdset_create_localhost("disk_avgsz", diskstat.name, NULL, diskstat.name, "disk.avgsz"
+                                                         , "Average Completed I/O Operation Bandwidth"
+                                                         , "kilobytes per operation", 2006, update_every
+                                                         , RRDSET_TYPE_AREA);
+                            rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                            rrddim_add(st, "reads", NULL, 1, 1024, RRDDIM_ABSOLUTE);
-                            rrddim_add(st, "writes", NULL, -1, 1024, RRDDIM_ABSOLUTE);
+                            rrddim_add(st, "reads", NULL, 1, 1024, RRD_ALGORITHM_ABSOLUTE);
+                            rrddim_add(st, "writes", NULL, -1, 1024, RRD_ALGORITHM_ABSOLUTE);
                         }
                         else rrdset_next(st);
 
@@ -272,12 +285,14 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                         // --------------------------------------------------------------------
 
-                        st = rrdset_find_bytype("disk_svctm", diskstat.name);
+                        st = rrdset_find_bytype_localhost("disk_svctm", diskstat.name);
                         if (unlikely(!st)) {
-                            st = rrdset_create("disk_svctm", diskstat.name, NULL, diskstat.name, "disk.svctm", "Average Service Time", "ms per operation", 2007, update_every, RRDSET_TYPE_LINE);
-                            st->isdetail = 1;
+                            st = rrdset_create_localhost("disk_svctm", diskstat.name, NULL, diskstat.name, "disk.svctm"
+                                                         , "Average Service Time", "ms per operation", 2007
+                                                         , update_every, RRDSET_TYPE_LINE);
+                            rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                            rrddim_add(st, "svctm", NULL, 1, 1000000, RRDDIM_ABSOLUTE);
+                            rrddim_add(st, "svctm", NULL, 1, 1000000, RRD_ALGORITHM_ABSOLUTE);
                         }
                         else rrdset_next(st);
 
@@ -301,11 +316,12 @@ int do_macos_iokit(int update_every, usec_t dt) {
     }
 
     if (likely(do_io)) {
-        st = rrdset_find_bytype("system", "io");
+        st = rrdset_find_bytype_localhost("system", "io");
         if (unlikely(!st)) {
-            st = rrdset_create("system", "io", NULL, "disk", NULL, "Disk I/O", "kilobytes/s", 150, update_every, RRDSET_TYPE_AREA);
-            rrddim_add(st, "in",  NULL,  1, 1024, RRDDIM_INCREMENTAL);
-            rrddim_add(st, "out", NULL, -1, 1024, RRDDIM_INCREMENTAL);
+            st = rrdset_create_localhost("system", "io", NULL, "disk", NULL, "Disk I/O", "kilobytes/s", 150
+                                         , update_every, RRDSET_TYPE_AREA);
+            rrddim_add(st, "in",  NULL,  1, 1024, RRD_ALGORITHM_INCREMENTAL);
+            rrddim_add(st, "out", NULL, -1, 1024, RRD_ALGORITHM_INCREMENTAL);
         }
         else rrdset_next(st);
 
@@ -340,17 +356,17 @@ int do_macos_iokit(int update_every, usec_t dt) {
                 // --------------------------------------------------------------------------
 
                 if (likely(do_space)) {
-                    st = rrdset_find_bytype("disk_space", mntbuf[i].f_mntonname);
+                    st = rrdset_find_bytype_localhost("disk_space", mntbuf[i].f_mntonname);
                     if (unlikely(!st)) {
                         snprintfz(title, 4096, "Disk Space Usage for %s [%s]", mntbuf[i].f_mntonname, mntbuf[i].f_mntfromname);
-                        st = rrdset_create("disk_space", mntbuf[i].f_mntonname, NULL, mntbuf[i].f_mntonname, "disk.space", title, "GB", 2023,
-                                           update_every,
-                                           RRDSET_TYPE_STACKED);
+                        st = rrdset_create_localhost("disk_space", mntbuf[i].f_mntonname, NULL, mntbuf[i].f_mntonname
+                                                     , "disk.space", title, "GB", 2023, update_every
+                                                     , RRDSET_TYPE_STACKED);
 
-                        rrddim_add(st, "avail", NULL, mntbuf[i].f_bsize, GIGA_FACTOR, RRDDIM_ABSOLUTE);
-                        rrddim_add(st, "used", NULL, mntbuf[i].f_bsize, GIGA_FACTOR, RRDDIM_ABSOLUTE);
+                        rrddim_add(st, "avail", NULL, mntbuf[i].f_bsize, GIGA_FACTOR, RRD_ALGORITHM_ABSOLUTE);
+                        rrddim_add(st, "used", NULL, mntbuf[i].f_bsize, GIGA_FACTOR, RRD_ALGORITHM_ABSOLUTE);
                         rrddim_add(st, "reserved_for_root", "reserved for root", mntbuf[i].f_bsize, GIGA_FACTOR,
-                                   RRDDIM_ABSOLUTE);
+                                   RRD_ALGORITHM_ABSOLUTE);
                     } else
                         rrdset_next(st);
 
@@ -363,15 +379,16 @@ int do_macos_iokit(int update_every, usec_t dt) {
                 // --------------------------------------------------------------------------
 
                 if (likely(do_inodes)) {
-                    st = rrdset_find_bytype("disk_inodes", mntbuf[i].f_mntonname);
+                    st = rrdset_find_bytype_localhost("disk_inodes", mntbuf[i].f_mntonname);
                     if (unlikely(!st)) {
                         snprintfz(title, 4096, "Disk Files (inodes) Usage for %s [%s]", mntbuf[i].f_mntonname, mntbuf[i].f_mntfromname);
-                        st = rrdset_create("disk_inodes", mntbuf[i].f_mntonname, NULL, mntbuf[i].f_mntonname, "disk.inodes", title, "Inodes", 2024,
-                                           update_every, RRDSET_TYPE_STACKED);
+                        st = rrdset_create_localhost("disk_inodes", mntbuf[i].f_mntonname, NULL, mntbuf[i].f_mntonname
+                                                     , "disk.inodes", title, "Inodes", 2024, update_every
+                                                     , RRDSET_TYPE_STACKED);
 
-                        rrddim_add(st, "avail", NULL, 1, 1, RRDDIM_ABSOLUTE);
-                        rrddim_add(st, "used", NULL, 1, 1, RRDDIM_ABSOLUTE);
-                        rrddim_add(st, "reserved_for_root", "reserved for root", 1, 1, RRDDIM_ABSOLUTE);
+                        rrddim_add(st, "avail", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+                        rrddim_add(st, "used", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+                        rrddim_add(st, "reserved_for_root", "reserved for root", 1, 1, RRD_ALGORITHM_ABSOLUTE);
                     } else
                         rrdset_next(st);
 
@@ -398,12 +415,13 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                 // --------------------------------------------------------------------
 
-                st = rrdset_find_bytype("net", ifa->ifa_name);
+                st = rrdset_find_bytype_localhost("net", ifa->ifa_name);
                 if (unlikely(!st)) {
-                    st = rrdset_create("net", ifa->ifa_name, NULL, ifa->ifa_name, "net.net", "Bandwidth", "kilobits/s", 7000, update_every, RRDSET_TYPE_AREA);
+                    st = rrdset_create_localhost("net", ifa->ifa_name, NULL, ifa->ifa_name, "net.net", "Bandwidth"
+                                                 , "kilobits/s", 7000, update_every, RRDSET_TYPE_AREA);
 
-                    rrddim_add(st, "received", NULL, 8, 1024, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "sent", NULL, -8, 1024, RRDDIM_INCREMENTAL);
+                    rrddim_add(st, "received", NULL, 8, 1024, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "sent", NULL, -8, 1024, RRD_ALGORITHM_INCREMENTAL);
                 }
                 else rrdset_next(st);
 
@@ -413,15 +431,16 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                 // --------------------------------------------------------------------
 
-                st = rrdset_find_bytype("net_packets", ifa->ifa_name);
+                st = rrdset_find_bytype_localhost("net_packets", ifa->ifa_name);
                 if (unlikely(!st)) {
-                    st = rrdset_create("net_packets", ifa->ifa_name, NULL, ifa->ifa_name, "net.packets", "Packets", "packets/s", 7001, update_every, RRDSET_TYPE_LINE);
-                    st->isdetail = 1;
+                    st = rrdset_create_localhost("net_packets", ifa->ifa_name, NULL, ifa->ifa_name, "net.packets"
+                                                 , "Packets", "packets/s", 7001, update_every, RRDSET_TYPE_LINE);
+                    rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                    rrddim_add(st, "received", NULL, 1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "sent", NULL, -1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "multicast_received", NULL, 1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "multicast_sent", NULL, -1, 1, RRDDIM_INCREMENTAL);
+                    rrddim_add(st, "received", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "sent", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "multicast_received", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "multicast_sent", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
                 }
                 else rrdset_next(st);
 
@@ -433,13 +452,14 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                 // --------------------------------------------------------------------
 
-                st = rrdset_find_bytype("net_errors", ifa->ifa_name);
+                st = rrdset_find_bytype_localhost("net_errors", ifa->ifa_name);
                 if (unlikely(!st)) {
-                    st = rrdset_create("net_errors", ifa->ifa_name, NULL, ifa->ifa_name, "net.errors", "Interface Errors", "errors/s", 7002, update_every, RRDSET_TYPE_LINE);
-                    st->isdetail = 1;
+                    st = rrdset_create_localhost("net_errors", ifa->ifa_name, NULL, ifa->ifa_name, "net.errors"
+                                                 , "Interface Errors", "errors/s", 7002, update_every, RRDSET_TYPE_LINE);
+                    rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                    rrddim_add(st, "inbound", NULL, 1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "outbound", NULL, -1, 1, RRDDIM_INCREMENTAL);
+                    rrddim_add(st, "inbound", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "outbound", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
                 }
                 else rrdset_next(st);
 
@@ -449,12 +469,13 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                 // --------------------------------------------------------------------
 
-                st = rrdset_find_bytype("net_drops", ifa->ifa_name);
+                st = rrdset_find_bytype_localhost("net_drops", ifa->ifa_name);
                 if (unlikely(!st)) {
-                    st = rrdset_create("net_drops", ifa->ifa_name, NULL, ifa->ifa_name, "net.drops", "Interface Drops", "drops/s", 7003, update_every, RRDSET_TYPE_LINE);
-                    st->isdetail = 1;
+                    st = rrdset_create_localhost("net_drops", ifa->ifa_name, NULL, ifa->ifa_name, "net.drops"
+                                                 , "Interface Drops", "drops/s", 7003, update_every, RRDSET_TYPE_LINE);
+                    rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                    rrddim_add(st, "inbound", NULL, 1, 1, RRDDIM_INCREMENTAL);
+                    rrddim_add(st, "inbound", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
                 }
                 else rrdset_next(st);
 
@@ -463,14 +484,16 @@ int do_macos_iokit(int update_every, usec_t dt) {
 
                 // --------------------------------------------------------------------
 
-                st = rrdset_find_bytype("net_events", ifa->ifa_name);
+                st = rrdset_find_bytype_localhost("net_events", ifa->ifa_name);
                 if (unlikely(!st)) {
-                    st = rrdset_create("net_events", ifa->ifa_name, NULL, ifa->ifa_name, "net.events", "Network Interface Events", "events/s", 7006, update_every, RRDSET_TYPE_LINE);
-                    st->isdetail = 1;
+                    st = rrdset_create_localhost("net_events", ifa->ifa_name, NULL, ifa->ifa_name, "net.events"
+                                                 , "Network Interface Events", "events/s", 7006, update_every
+                                                 , RRDSET_TYPE_LINE);
+                    rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
 
-                    rrddim_add(st, "frames", NULL, 1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "collisions", NULL, -1, 1, RRDDIM_INCREMENTAL);
-                    rrddim_add(st, "carrier", NULL, -1, 1, RRDDIM_INCREMENTAL);
+                    rrddim_add(st, "frames", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "collisions", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
+                    rrddim_add(st, "carrier", NULL, -1, 1, RRD_ALGORITHM_INCREMENTAL);
                 }
                 else rrdset_next(st);
 
