@@ -2,8 +2,6 @@
 
 struct plugind *pluginsd_root = NULL;
 
-#define MAX_WORDS 20
-
 static inline int pluginsd_space(char c) {
     switch(c) {
     case ' ':
@@ -18,7 +16,8 @@ static inline int pluginsd_space(char c) {
     }
 }
 
-static int pluginsd_split_words(char *str, char **words, int max_words) {
+// split a text into words, respecting quotes
+inline int pluginsd_split_words(char *str, char **words, int max_words) {
     char *s = str, quote = 0;
     int i = 0, j;
 
@@ -95,14 +94,13 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
 
     char line[PLUGINSD_LINE_MAX + 1];
 
-    char *words[MAX_WORDS] = { NULL };
-    /* uint32_t HOST_HASH = simple_hash("HOST"); */
-    uint32_t BEGIN_HASH = simple_hash("BEGIN");
-    uint32_t END_HASH = simple_hash("END");
-    uint32_t FLUSH_HASH = simple_hash("FLUSH");
-    uint32_t CHART_HASH = simple_hash("CHART");
-    uint32_t DIMENSION_HASH = simple_hash("DIMENSION");
-    uint32_t DISABLE_HASH = simple_hash("DISABLE");
+    char *words[PLUGINSD_MAX_WORDS] = { NULL };
+    uint32_t BEGIN_HASH = simple_hash(PLUGINSD_KEYWORD_BEGIN);
+    uint32_t END_HASH = simple_hash(PLUGINSD_KEYWORD_END);
+    uint32_t FLUSH_HASH = simple_hash(PLUGINSD_KEYWORD_FLUSH);
+    uint32_t CHART_HASH = simple_hash(PLUGINSD_KEYWORD_CHART);
+    uint32_t DIMENSION_HASH = simple_hash(PLUGINSD_KEYWORD_DIMENSION);
+    uint32_t DISABLE_HASH = simple_hash(PLUGINSD_KEYWORD_DISABLE);
 
     RRDSET *st = NULL;
     uint32_t hash;
@@ -130,7 +128,7 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
 
         // debug(D_PLUGINSD, "PLUGINSD: %s: %s", cd->filename, line);
 
-        int w = pluginsd_split_words(line, words, MAX_WORDS);
+        int w = pluginsd_split_words(line, words, PLUGINSD_MAX_WORDS);
         char *s = words[0];
         if(unlikely(!s || !*s || !w)) {
             // debug(D_PLUGINSD, "PLUGINSD: empty line");
@@ -159,9 +157,18 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
 
             if(unlikely(rrdset_flag_check(st, RRDSET_FLAG_DEBUG))) debug(D_PLUGINSD, "PLUGINSD: '%s' is setting dimension %s/%s to %s", cd->fullfilename, st->id, dimension, value?value:"<nothing>");
 
-            if(value) rrddim_set(st, dimension, strtoll(value, NULL, 0));
+            if(value) {
+                RRDDIM *rd = rrddim_find(st, dimension);
+                if(unlikely(!rd)) {
+                    error("PLUGINSD: '%s' is requesting a SET to dimension with id '%s' on stats '%s' (%s) on host '%s', which does not exist. Disabling it.", cd->fullfilename, dimension, st->name, st->id, st->rrdhost->hostname);
+                    enabled = 0;
+                    break;
+                }
+                else
+                    rrddim_set_by_pointer(st, rd, strtoll(value, NULL, 0));
+            }
         }
-        else if(likely(hash == BEGIN_HASH && !strcmp(s, "BEGIN"))) {
+        else if(likely(hash == BEGIN_HASH && !strcmp(s, PLUGINSD_KEYWORD_BEGIN))) {
             char *id = words[1];
             char *microseconds_txt = words[2];
 
@@ -191,7 +198,7 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
                 else rrdset_next(st);
             }
         }
-        else if(likely(hash == END_HASH && !strcmp(s, "END"))) {
+        else if(likely(hash == END_HASH && !strcmp(s, PLUGINSD_KEYWORD_END))) {
             if(unlikely(!st)) {
                 error("PLUGINSD: '%s' is requesting an END, without a BEGIN on host '%s'. Disabling it.", cd->fullfilename, host->hostname);
                 enabled = 0;
@@ -205,28 +212,11 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
 
             count++;
         }
-/*        else if(likely(hash == HOST_HASH && !strcmp(s, "HOST"))) {
-            char *guid = words[1];
-            char *hostname = words[2];
-
-            if(unlikely(!guid || !*guid)) {
-                error("PLUGINSD: '%s' is requesting HOST with guid '%s' and hostname '%s', without a guid. Disabling it.", cd->fullfilename, guid?guid:"", hostname?hostname:"");
-                enabled = 0;
-                break;
-            }
-            if(unlikely(!hostname || !*hostname)) {
-                error("PLUGINSD: '%s' is requesting HOST with guid '%s' and hostname '%s', without a hostname. Disabling it.", cd->fullfilename, guid?guid:"", hostname?hostname:"");
-                enabled = 0;
-                break;
-            }
-
-            host = rrdhost_find_or_create(hostname, guid);
-        } */
-        else if(likely(hash == FLUSH_HASH && !strcmp(s, "FLUSH"))) {
+        else if(likely(hash == FLUSH_HASH && !strcmp(s, PLUGINSD_KEYWORD_FLUSH))) {
             debug(D_PLUGINSD, "PLUGINSD: '%s' is requesting a FLUSH", cd->fullfilename);
             st = NULL;
         }
-        else if(likely(hash == CHART_HASH && !strcmp(s, "CHART"))) {
+        else if(likely(hash == CHART_HASH && !strcmp(s, PLUGINSD_KEYWORD_CHART))) {
             int noname = 0;
             st = NULL;
 
@@ -247,6 +237,7 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
             char *chart = words[7];
             char *priority_s = words[8];
             char *update_every_s = words[9];
+            char *options = words[10];
 
             if(unlikely(!type || !*type || !id || !*id)) {
                 error("PLUGINSD: '%s' is requesting a CHART, without a type.id, on host '%s'. Disabling it.", cd->fullfilename, host->hostname);
@@ -284,8 +275,25 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
                 cd->update_every = update_every;
             }
             else debug(D_PLUGINSD, "PLUGINSD: Chart '%s' already exists. Not adding it again.", st->id);
+
+            if(options && *options) {
+                if(strstr(options, "obsolete"))
+                    rrdset_is_obsolete(st);
+                else
+                    rrdset_isnot_obsolete(st);
+
+                if(strstr(options, "detail"))
+                    rrdset_flag_set(st, RRDSET_FLAG_DETAIL);
+                else
+                    rrdset_flag_clear(st, RRDSET_FLAG_DETAIL);
+
+                if(strstr(options, "store_first"))
+                    rrdset_flag_set(st, RRDSET_FLAG_STORE_FIRST);
+                else
+                    rrdset_flag_clear(st, RRDSET_FLAG_STORE_FIRST);
+            }
         }
-        else if(likely(hash == DIMENSION_HASH && !strcmp(s, "DIMENSION"))) {
+        else if(likely(hash == DIMENSION_HASH && !strcmp(s, PLUGINSD_KEYWORD_DIMENSION))) {
             char *id = words[1];
             char *name = words[2];
             char *algorithm = words[3];
@@ -326,21 +334,16 @@ inline size_t pluginsd_process(RRDHOST *host, struct plugind *cd, FILE *fp, int
                       , options?options:""
                 );
 
-            RRDDIM *rd = rrddim_find(st, id);
-            if(unlikely(!rd)) {
-                rd = rrddim_add(st, id, name, multiplier, divisor, rrd_algorithm_id(algorithm));
-                rrddim_flag_clear(rd, RRDDIM_FLAG_HIDDEN);
-                rrddim_flag_clear(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
-                if(options && *options) {
-                    if(strstr(options, "hidden") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_HIDDEN);
-                    if(strstr(options, "noreset") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
-                    if(strstr(options, "nooverflow") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
-                }
+            RRDDIM *rd = rrddim_add(st, id, name, multiplier, divisor, rrd_algorithm_id(algorithm));
+            rrddim_flag_clear(rd, RRDDIM_FLAG_HIDDEN);
+            rrddim_flag_clear(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
+            if(options && *options) {
+                if(strstr(options, "hidden") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_HIDDEN);
+                if(strstr(options, "noreset") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
+                if(strstr(options, "nooverflow") != NULL) rrddim_flag_set(rd, RRDDIM_FLAG_DONT_DETECT_RESETS_OR_OVERFLOWS);
             }
-            else if(unlikely(rrdset_flag_check(st, RRDSET_FLAG_DEBUG)))
-                debug(D_PLUGINSD, "PLUGINSD: dimension %s/%s already exists. Not adding it again.", st->id, id);
         }
-        else if(unlikely(hash == DISABLE_HASH && !strcmp(s, "DISABLE"))) {
+        else if(unlikely(hash == DISABLE_HASH && !strcmp(s, PLUGINSD_KEYWORD_DISABLE))) {
             info("PLUGINSD: '%s' called DISABLE. Disabling it.", cd->fullfilename);
             enabled = 0;
             break;
