@@ -57,13 +57,7 @@ struct web_client *web_client_create(int listener) {
     w->mode = WEB_CLIENT_MODE_NORMAL;
 
     {
-        struct sockaddr *sadr;
-        socklen_t addrlen;
-
-        sadr = (struct sockaddr*) &w->clientaddr;
-        addrlen = sizeof(w->clientaddr);
-
-        w->ifd = accept4(listener, sadr, &addrlen, SOCK_NONBLOCK);
+        w->ifd = accept_socket(listener, SOCK_NONBLOCK, w->client_ip, sizeof(w->client_ip), w->client_port, sizeof(w->client_port));
         if (w->ifd == -1) {
             error("%llu: Cannot accept new incoming connection.", w->id);
             freez(w);
@@ -71,33 +65,6 @@ struct web_client *web_client_create(int listener) {
         }
         w->ofd = w->ifd;
 
-        if(getnameinfo(sadr, addrlen, w->client_ip, NI_MAXHOST, w->client_port, NI_MAXSERV, NI_NUMERICHOST | NI_NUMERICSERV) != 0) {
-            error("Cannot getnameinfo() on received client connection.");
-            strncpyz(w->client_ip,   "UNKNOWN", NI_MAXHOST);
-            strncpyz(w->client_port, "UNKNOWN", NI_MAXSERV);
-        }
-        w->client_ip[NI_MAXHOST]   = '\0';
-        w->client_port[NI_MAXSERV] = '\0';
-
-        switch(sadr->sa_family) {
-        case AF_INET:
-            debug(D_WEB_CLIENT_ACCESS, "%llu: New IPv4 web client from %s port %s on socket %d.", w->id, w->client_ip, w->client_port, w->ifd);
-            break;
-
-        case AF_INET6:
-            if(strncmp(w->client_ip, "::ffff:", 7) == 0) {
-                memmove(w->client_ip, &w->client_ip[7], strlen(&w->client_ip[7]) + 1);
-                debug(D_WEB_CLIENT_ACCESS, "%llu: New IPv4 web client from %s port %s on socket %d.", w->id, w->client_ip, w->client_port, w->ifd);
-            }
-            else
-                debug(D_WEB_CLIENT_ACCESS, "%llu: New IPv6 web client from %s port %s on socket %d.", w->id, w->client_ip, w->client_port, w->ifd);
-            break;
-
-        default:
-            debug(D_WEB_CLIENT_ACCESS, "%llu: New UNKNOWN web client from %s port %s on socket %d.", w->id, w->client_ip, w->client_port, w->ifd);
-            break;
-        }
-
         int flag = 1;
         if(setsockopt(w->ofd, IPPROTO_TCP, TCP_NODELAY, (char *) &flag, sizeof(int)) != 0)
             error("%llu: failed to enable TCP_NODELAY on socket.", w->id);
@@ -388,8 +355,8 @@ int mysendfile(struct web_client *w, char *filename) {
             return 404;
         }
     }
-    if(fcntl(w->ifd, F_SETFL, O_NONBLOCK) < 0)
-        error("%llu: Cannot set O_NONBLOCK on file '%s'.", w->id, webfilename);
+
+    sock_setnonblock(w->ifd);
 
     // pick a Content-Type for the file
          if(strstr(filename, ".html") != NULL)  w->response.data->contenttype = CT_TEXT_HTML;
@@ -995,13 +962,22 @@ static inline void web_client_send_http_header(struct web_client *w) {
 
     web_client_crock_socket(w);
 
-    ssize_t bytes = send(w->ofd, buffer_tostring(w->response.header_output), buffer_strlen(w->response.header_output), 0);
+    size_t count = 0;
+    ssize_t bytes;
+    while((bytes = send(w->ofd, buffer_tostring(w->response.header_output), buffer_strlen(w->response.header_output), 0)) == -1) {
+        count++;
+
+        if(count > 100 || (errno != EAGAIN && errno != EWOULDBLOCK)) {
+            error("Cannot send HTTP headers to web client.");
+            break;
+        }
+    }
+
     if(bytes != (ssize_t) buffer_strlen(w->response.header_output)) {
         if(bytes > 0)
             w->stats_sent_bytes += bytes;
 
-        debug(D_WEB_CLIENT, "%llu: HTTP Header failed to be sent (I sent %zu bytes but the system sent %zd bytes). Closing web client."
-              , w->id
+        error("HTTP headers failed to be sent (I sent %zu bytes but the system sent %zd bytes). Closing web client."
               , buffer_strlen(w->response.header_output)
               , bytes);
 
